from fabric.api import *
from fabric.contrib.console import confirm


@task(default=True)
def new():
    current_branch = local("git branch | grep '*'", capture=True)[2:]
    restricted_branches = [env.staging_branch, env.production_branch]
    for branch in restricted_branches:
        if branch == current_branch:
            abort(
                "You cannot create pull requests from the "
                "%s branch." % branch)

    local("git push origin %s" % current_branch)
    if confirm("Is this merge associated with a GitHub issue?", default=True):
        issue = prompt(
            "What is the issue number?",
            validate=int)
        local("hub pull-request -i %d -b %s" % (issue, env.production_branch))
    else:
        title = prompt("Title:")
        local(
            "hub pull-request \"%s\" -b %s" % (title, env.production_branch))

    if confirm(("Pull-request complete.  "
                "Delete your branch '%s'?" % current_branch), default=False):
        local("git checkout %s" % env.production_branch)
        local("git branch -d %s" % current_branch)



from fabric.api import *
from fabric.contrib.console import confirm
from django.conf import settings


def refresh():
    db_name = settings.DATABASES['default']['NAME']
    if not confirm("Are you sure you want to drop your "
                   "%s database?" % db_name):
        abort("Refresh cancelled.")

    _system_date = "`date +\%Y\%m\%d`"
    sql_file_name = "%s.%s.sql.bz2" % (env.project_name, _system_date)

    dropdb = local("dropdb %s" % db_name)
    if dropdb.failed:
        print("Info: %s does not exist" % db_name)
    local("createdb %s" % db_name)
    base_path = "%s:/var/backups" % env.roledefs[env.refresh_role][0]
    local("scp %s/%s/sql/%s ." % (base_path, env.project_name, sql_file_name))
    local("bzcat %s | psql %s > /dev/null" % (sql_file_name, db_name))
    local("rm %s" % sql_file_name)
    local("rsync -vauz --delete %s/%s/media/ media" % (
        base_path, env.project_name))
    if 'haystack' in settings.INSTALLED_APPS:
        local("python manage.py rebuild_index --noinput")


def _validate_refresh_role(refresh_role):
    refresh_role = refresh_role.strip().lower()
    if refresh_role not in env.roledefs.keys():
        raise ValueError(
            "Choose one of %s." % ' or '.join(env.roledefs.keys()))
    return refresh_role


def get_refresh_role():
    if len(env.roledefs) > 1:
        prompt((
            "Which server would you like to refresh from "
            "(%s)?" % ' or '.join(env.roledefs.keys())),
            'refresh_role',
            default=env.roledefs.keys()[0],
            validate=_validate_refresh_role)
    else:
        env.refresh_role = env.roledefs.keys()[0]


@task(default=True)
def interactive():
    get_refresh_role()
    execute(refresh, role=env.refresh_role)



from fabric.api import env
from fabric.contrib import django

import deploy
import pull_request
import refresh
import stage
import sync
import topic


repr(deploy)
repr(pull_request)
repr(refresh)
repr(stage)
repr(sync)
repr(topic)


required_settings = [
    'repo_source',
    'project_name',
    'django_settings_module',
    'django_test_settings_module']
for required_setting in required_settings:
    if not hasattr(env, required_setting):
        raise RuntimeError('You must set %s in fabfile.py' % required_setting)

env.production_branch = getattr(env, 'production_branch', 'master')
env.staging_branch = getattr(env, 'staging_branch', 'staging')

django.settings_module(env.django_settings_module)



#!/usr/bin/env python
"""
Automation
==========

Automation is a Django-specific implementation of Fabric that provides
automation for server and git repository tasks.

:copyright: (c) 2013 by Dustin Farris
:license: BSD, see LICENSE for more details

"""

from setuptools import setup, find_packages


tests_require = []

install_requires = [
    'Django>=1.4,<1.5',
    'Fabric==1.5.2']

setup(
    name='automation',
    version='0.3.3.5',
    author='Dustin Farris',
    author_email='dustin@dustinfarris.com',
    url='https://github.com/dustinfarris/automation',
    description='A Django-specific implementation of Fabric',
    long_description=__doc__,
    package_dir={'': 'src'},
    packages=find_packages('src'),
    zip_safe=False,
    install_requires=install_requires,
    tests_require=tests_require,
    test_suite='runtests.runtests',
    license='BSD',
    include_package_data=True,
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: System Administrators',
        'Operating System :: Unix',
        'Topic :: Internet :: WWW/HTTP :: HTTP Servers',
        'Topic :: Software Development :: Version Control',
        'Topic :: Software Development :: Quality Assurance'])



def choose(question, choices):
    """Ask user to choose from a list of enumerated choices."""
    print "\n%s\n" % question
    for number, choice in enumerate(choices, start=1):
        print "  %d) %s" % (number, str(choice))
    user_choice = raw_input("\n> ")
    print
    return choices[int(user_choice) - 1]
